@@ -1,41 +1,43 @@
 
-#' Generate code to create a \code{ggplot2}
+#' Generate code to create a `ggplot2`
 #'
-#' @param data Character. Name of the \code{data.frame}.
+#' @param data Character. Name of the `data.frame`.
 #' @param mapping List. Named list of aesthetics.
 #' @param geom Character. Name of the geom to use (with or without "geom_").
 #' @param geom_args List. Arguments to use in the geom.
 #' @param scales Character vector. Scale(s) to use (with or without "scale_").
 #' @param scales_args List. Arguments to use in scale(s),
-#'  if \code{scales} is length > 1, must be a named list with \code{scales} names.
+#'  if `scales` is length > 1, must be a named list with `scales` names.
 #' @param coord Character. Coordinates to use (with or without "coord_").
+#' @param coord_args Arguments for coordinates function.
 #' @param labs List. Named list of labels to use for title, subtitle, x & y axis, legends.
 #' @param theme Character. Name of the theme to use (with or without "theme_").
-#' @param theme_args Named list. Arguments for \code{\link[ggplot2:theme]{theme}}.
-#' @param facet Character vector. Names of variables to use in \code{\link[ggplot2]{facet_wrap}}.
-#' @param facet_row Character vector. Names of row variables to use in \code{\link[ggplot2]{facet_grid}}.
-#' @param facet_col Character vector. Names of col variables to use in \code{\link[ggplot2]{facet_grid}}.
-#' @param facet_args Named list. Arguments for \code{\link[ggplot2:facet_wrap]{facet_wrap}}.
+#' @param theme_args Named list. Arguments for [ggplot2::theme()].
+#' @param facet Character vector. Names of variables to use in [ggplot2::facet_wrap].
+#' @param facet_row Character vector. Names of row variables to use in [ggplot2::facet_grid()].
+#' @param facet_col Character vector. Names of col variables to use in [ggplot2::facet_grid()].
+#' @param facet_args Named list. Arguments for [ggplot2::facet_wrap()].
 #' @param xlim A vector of length 2 representing limits on x-axis.
 #' @param ylim A vector of length 2 representing limits on y-axis.
 #'
-#' @return a \code{call} that can be evaluated with \code{eval}.
+#' @return a `call` that can be evaluated with `eval`.
 #' @export
-#' 
+#'
 #' @importFrom stats setNames
 #' @importFrom rlang sym syms expr as_name is_call call2 has_length
 #' @importFrom ggplot2 ggplot aes theme facet_wrap vars coord_flip labs
 #'
 #' @example examples/ex-ggcall.R
 ggcall <- function(data = NULL,
-                   mapping = NULL, 
-                   geom = NULL, 
+                   mapping = NULL,
+                   geom = NULL,
                    geom_args = list(),
-                   scales = NULL, 
+                   scales = NULL,
                    scales_args = list(),
-                   coord = NULL, 
-                   labs = list(), 
-                   theme = NULL, 
+                   coord = NULL,
+                   coord_args = list(),
+                   labs = list(),
+                   theme = NULL,
                    theme_args = list(),
                    facet = NULL,
                    facet_row = NULL,
@@ -48,28 +50,40 @@ ggcall <- function(data = NULL,
   if (!is_call(data)) {
     data <- as.character(data)
     if (grepl("::", data)) {
-      data <- str2lang(data) 
+      data <- str2lang(data)
     } else {
       data <- sym(data)
     }
   }
-  if (rlang::is_call(mapping)) 
+  if (rlang::is_call(mapping))
     mapping <- eval(mapping)
   mapping <- dropNulls(mapping)
-  aes <- expr(aes(!!!syms2(mapping)))
-  ggcall <- expr(ggplot(!!data) + !!aes)
+  if (length(mapping) > 0) {
+    aes <- expr(aes(!!!syms2(mapping)))
+    ggcall <- expr(ggplot(!!data) + !!aes)
+  } else {
+    ggcall <- expr(ggplot(!!data))
+  }
   if (length(geom) == 1)
-    geom_args <- setNames(list(geom_args), geom)
-  for (g in geom) {
-    g_args <- dropNulls(geom_args[[g]])
-    if (!grepl("^geom_", g))
-      g <- paste0("geom_", g)
-    geom <- call2(g, !!!g_args)
-    ggcall <- expr(!!ggcall + !!geom)
+    geom_args <- list(geom_args)
+  for (ig in seq_along(geom)) {
+    g_nm <- geom[ig]
+    if (ig <= length(geom_args)) {
+      g_args <- dropNulls(geom_args[[ig]])
+    } else {
+      g_args <- list()
+    }
+    if (!grepl("^geom_", g_nm))
+      g_nm <- paste0("geom_", g_nm)
+    geomcall <- call2(g_nm, !!!g_args)
+    ggcall <- expr(!!ggcall + !!geomcall)
   }
   if (!is.null(scales)) {
     if (length(scales) == 1 && !isTRUE(grepl(scales, names(scales_args))))
       scales_args <- setNames(list(scales_args), scales)
+    scales_dup <- duplicated(scales, fromLast = TRUE)
+    scales_args <- scales_args[!scales_dup]
+    scales <- scales[!scales_dup]
     for (s in scales) {
       s_args <- dropNulls(scales_args[[s]])
       if (grepl("::", x = s)) {
@@ -91,7 +105,7 @@ ggcall <- function(data = NULL,
   if (!is.null(coord)) {
     if (!grepl("^coord_", coord))
       coord <- paste0("coord_", coord)
-    coord <- call2(coord)
+    coord <- call2(coord, !!!coord_args)
     ggcall <- expr(!!ggcall + !!coord)
   }
   if (!is.null(theme)) {
@@ -134,7 +148,7 @@ ggcall <- function(data = NULL,
       ggcall <- expr(!!ggcall + !!facet)
     }
   }
-  
+
   if (has_length(xlim, 2)) {
     xlim <- expr(xlim(!!!as.list(xlim)))
     ggcall <- expr(!!ggcall + !!xlim)
@@ -143,7 +157,7 @@ ggcall <- function(data = NULL,
     ylim <- expr(ylim(!!!as.list(ylim)))
     ggcall <- expr(!!ggcall + !!ylim)
   }
-  
+
   ggcall
 }
 
