@@ -72,7 +72,7 @@ toggleDisplay <- function(id,
   }
   session$sendCustomMessage(
     type = "toggleDisplay",
-    message = list(id = id, display = display)
+    message = list(id = session$ns(id), display = display)
   )
 }
 
@@ -86,7 +86,8 @@ toggleDisplay <- function(id,
 #' @param session shiny session.
 #'
 #' @noRd
-toggleBtn <- function(inputId, type = "disable",
+toggleBtn <- function(inputId,
+                      type = "disable",
                       session = shiny::getDefaultReactiveDomain()) {
   session$sendCustomMessage(
     type = "togglewidget",
@@ -96,16 +97,6 @@ toggleBtn <- function(inputId, type = "disable",
 
 
 
-#' Tag to display code
-#'
-#' @param ... Character strings
-#'
-#' @noRd
-rCodeContainer <- function(...) {
-  code <- htmltools::HTML(as.character(tags$code(class = "language-r", ...)))
-  htmltools::tags$div(htmltools::tags$pre(code))
-}
-
 
 #' @importFrom shinyWidgets prettyToggle
 #' @importFrom htmltools css
@@ -172,9 +163,14 @@ activate_resizer <- function(id,
 resize <- function(id,
                    width,
                    height,
+                   with_moveable = TRUE,
                    session = shiny::getDefaultReactiveDomain()) {
-  session$sendCustomMessage(paste0("resize-", id), list(
-    width = width,
-    height = height
-  ))
+  session$sendCustomMessage(
+    if (isTRUE(with_moveable)) paste0("resize-", id) else "esquisse-resize-plot",
+    list(
+      id = id,
+      width = width,
+      height = height
+    )
+  )
 }
